@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP          #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
@@ -38,10 +37,6 @@
 
 module Diagrams.Animation.Active where
 
-#if __GLASGOW_HASKELL__ < 710
-import           Control.Applicative (pure, (<$>))
-#endif
-
 import           Diagrams.Core
 import           Diagrams.TrailLike
 
