@@ -23,7 +23,7 @@
 -- executables.
 --
 -- For a tutorial on command-line diagram creation see
--- <http://projects.haskell.org/diagrams/doc/cmdline.html>.
+-- <https://diagrams.github.io/doc/cmdline.html>.
 --
 -----------------------------------------------------------------------------
 
@@ -98,6 +98,7 @@ import           Data.Colour.SRGB
 import           Data.Data
 import           Data.Functor.Identity
 import           Data.IORef
+import           Data.Kind                 (Type)
 import           Data.List                 (delete)
 import           Data.Maybe                (fromMaybe)
 import           Data.Monoid
@@ -220,11 +221,17 @@ diagramLoopOpts = DiagramLoopOpts
 --   Taken from Options.Applicative.Extra but without the
 --   short option 'h'.  We want the 'h' for Height.
 helper' :: Parser (a -> a)
-helper' = abortOption ShowHelpText $ mconcat
+helper' = abortOption param $ mconcat
   [ long "help"
   , short '?'
   , help "Show this help text"
   ]
+  where
+#if MIN_VERSION_optparse_applicative(0,16,0)
+    param = ShowHelpText Nothing
+#else
+    param = ShowHelpText 
+#endif
 
 -- | Apply a parser to the command line that includes the standard
 --   program description and help behavior.  Results in parsed commands
@@ -355,8 +362,8 @@ instance (Parseable a, Parseable b, Parseable c, Parseable d) => Parseable (a, b
 --   at once, and a type @'ResultOf' d@ that is the type of the final result from
 --   some base case instance.
 class ToResult d where
-  type Args d :: *
-  type ResultOf d :: *
+  type Args d :: Type
+  type ResultOf d :: Type
 
   toResult :: d -> Args d -> ResultOf d
 
@@ -430,7 +437,7 @@ instance ToResult d => ToResult (a -> d) where
 class Mainable d where
   -- | Associated type that describes the options which need to be parsed
   -- from the command-line and passed to @mainRender@.
-  type MainOpts d :: *
+  type MainOpts d :: Type
 
   -- | This method invokes the command-line parser resulting in an options
   -- value or ending the program with an error or help message.
