@@ -18,7 +18,7 @@
 --
 -- Drawing arrows in two dimensions.  For a tutorial on drawing arrows
 -- using this module, see the diagrams website:
--- <http://projects.haskell.org/diagrams/doc/arrow.html>.
+-- <https://diagrams.github.io/doc/arrow.html>.
 --
 -----------------------------------------------------------------------------
 
@@ -401,7 +401,7 @@ arrow' opts len = mkQD' (DelayedLeaf delayedArrow)
     -- uniformly as the transformation applied to the entire arrow.
     -- See https://github.com/diagrams/diagrams-lib/issues/112.
     delayedArrow da g n =
-      let (trans, globalSty) = option mempty untangle . fst $ da
+      let (trans, globalSty) = maybe mempty untangle . fst $ da
       in  dArrow globalSty trans len g n
 
     -- Build an arrow and set its endpoints to the image under tr of origin and (len,0).
